#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from zope.interface import Attribute, Interface
from zope.schema import Text, TextLine

from pyams_content.features.footer import IFooterRendererSettings
from pyams_content.shared.form import WfForm
from pyams_gis.schema import GeoPointField


__docformat__ = 'restructuredtext'

from pyams_almond_theme import _
from pyams_sequence.schema import InternalReferenceField


class IAlmondThemeFooterRendererSettings(IFooterRendererSettings):
    """PyAMS Almond theme footer renderer settings"""

    phone_number = TextLine(title=_("Phone number"),
                            required=False)

    email = TextLine(title=_("Email address"),
                     required=False)

    address = Text(title=_("Postal address"),
                   required=False)

    position = GeoPointField(title=_("GPS position"),
                             required=False)

    opening_hours = Text(title=_("Opening hours"),
                         required=False)

    contact_form = InternalReferenceField(title=_("Contact form"),
                                          description=_("Internal link to contact form"),
                                          content_type=WfForm.content_type,
                                          required=False)

    def get_contact_form_target(self):
        """Get internal reference to contact form"""

    contact_form_context = InternalReferenceField(title=_("Contact form context"),
                                                  description=_("If selected, this is the "
                                                                "context into which the contact "
                                                                "form will be displayed"),
                                                  required=False)

    def get_contact_form_context(self):
        """Get internal reference to contact form context"""

    copyright = TextLine(title=_("Copyright"),
                         required=False)

    menus = Attribute("Footer links")

    legals = Attribute("Legal contents links")


class IAlmondThemeFooterMenusContainer(Interface):
    """PyAMS Almond theme menus container marker interface"""


class IAlmondThemeFooterLegalsMenu(Interface):
    """PyAMS Almond theme legals links container marker interface"""
