#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from pyramid.location import lineage

from pyams_almond_theme.features.header import AlmondThemeHeaderRendererSettings, \
    IAlmondThemeHeaderRendererSettings
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.header import IHeaderRenderer, IHeaderRendererSettings, \
    IHeaderSettings, IHeaderTarget
from pyams_default_theme.features.header.skin import BaseHeaderRenderer
from pyams_sequence.interfaces import IInternalReference
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


__docformat__ = 'restructuredtext'

from pyams_almond_theme import _


ALMOND_HEADER_RENDERER_NAME = 'PyAMS almond header'


@adapter_config(name=ALMOND_HEADER_RENDERER_NAME,
                context=(IHeaderTarget, IPyAMSLayer),
                provides=IHeaderRenderer)
@adapter_config(name=ALMOND_HEADER_RENDERER_NAME,
                context=(IHeaderSettings, IPyAMSLayer),
                provides=IHeaderRenderer)
@template_config(template='templates/header.pt',
                 layer=IPyAMSLayer)
class AlmondThemeHeaderRenderer(BaseHeaderRenderer):
    """Almond theme header renderer"""

    name = ALMOND_HEADER_RENDERER_NAME
    label = _("PyAMS almond theme header")
    weight = 5

    settings_key = 'PyAMS::almond'
    settings_interface = IAlmondThemeHeaderRendererSettings

    def update(self):
        super().update()
        self.request.annotations['REQUEST_PATH'] = list(lineage(self.request.context))

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)

    def is_active(self, link):
        if IInternalReference.providedBy(link):
            target = link.get_target()
            if target is not None:
                return target in self.request.annotations['REQUEST_PATH']
        return False


@adapter_config(context=AlmondThemeHeaderRenderer,
                provides=IHeaderRendererSettings)
def almond_theme_header_renderer_settings_factory(context):
    """Almond theme header renderer settings factory"""
    return AlmondThemeHeaderRendererSettings()
